@@ -76,38 +76,6 @@ typedef enum {
 	AS_UTILS_LOCATION_LAST
 } AsUtilsLocation;
 
-/**
- * AsMarkupConvertFormat:
- * @AS_MARKUP_CONVERT_FORMAT_SIMPLE:		UTF-8 text
- * @AS_MARKUP_CONVERT_FORMAT_MARKDOWN:		Markdown format
- * @AS_MARKUP_CONVERT_FORMAT_NULL:		No output
- * @AS_MARKUP_CONVERT_FORMAT_APPSTREAM:		AppStream (passthrough)
- *
- * The output format used when converting AppStream descriptions.
- **/
-typedef enum {
-	AS_MARKUP_CONVERT_FORMAT_SIMPLE,
-	AS_MARKUP_CONVERT_FORMAT_MARKDOWN,
-	AS_MARKUP_CONVERT_FORMAT_NULL,		/* Since: 0.5.2 */
-	AS_MARKUP_CONVERT_FORMAT_APPSTREAM,	/* Since: 0.5.2 */
-	/*< private >*/
-	AS_MARKUP_CONVERT_FORMAT_LAST
-} AsMarkupConvertFormat;
-
-/**
- * AsMarkupConvertFlag:
- * @AS_MARKUP_CONVERT_FLAG_NONE:		No flags set
- * @AS_MARKUP_CONVERT_FLAG_IGNORE_ERRORS:	Ignore errors where possible
- *
- * The flags used when converting descriptions from AppStream-style.
- **/
-typedef enum {
-	AS_MARKUP_CONVERT_FLAG_NONE		= 0,
-	AS_MARKUP_CONVERT_FLAG_IGNORE_ERRORS	= 1 << 0,
-	/*< private >*/
-	AS_MARKUP_CONVERT_FLAG_LAST
-} AsMarkupConvertFlag;
-
 /**
  * AsVersionParseFlag:
  * @AS_VERSION_PARSE_FLAG_NONE:			No flags set
@@ -122,20 +90,6 @@ typedef enum {
 	AS_VERSION_PARSE_FLAG_LAST
 } AsVersionParseFlag;
 
-gchar		*as_markup_convert_simple	(const gchar	*markup,
-						 GError		**error);
-gchar		*as_markup_convert		(const gchar	*markup,
-						 AsMarkupConvertFormat format,
-						 GError		**error);
-gchar		*as_markup_convert_full		(const gchar	*markup,
-						 AsMarkupConvertFormat format,
-						 AsMarkupConvertFlag flags,
-						 GError		**error);
-gboolean	 as_markup_validate		(const gchar	*markup,
-						 GError		**error);
-gchar		**as_markup_strsplit_words	(const gchar	*text,
-						 guint		 line_len);
-
 GQuark		 as_utils_error_quark		(void);
 gboolean	 as_utils_is_stock_icon_name	(const gchar	*name);
 gboolean	 as_utils_is_spdx_license_id	(const gchar	*license_id);
@@ -172,6 +126,9 @@ gchar		*as_utils_version_from_uint32	(guint32	 val,
 gchar		*as_utils_version_from_uint16	(guint16	 val,
 						 AsVersionParseFlag flags);
 gchar		*as_utils_version_parse		(const gchar	*version);
+guint		 as_utils_string_replace	(GString	*string,
+						 const gchar	*search,
+						 const gchar	*replace);
 
 G_END_DECLS
 
